;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Empathy Power Model
;; Explore how power dynamics affect teams attempting to make prosocial decisions.
;; J M Applegate
;; November 2017
;; VERSION 1
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

extensions [palette nw array]

breed [avatars avatar]
breed [decisions decision]

globals
[ normal_dist gamma_dist reverse_gamma_dist mu vari alpha optimal yeas criteria A B communal non_communal ties choice p_communal previous
  baseline_values normaliser filename ]
;; on interface: rounds, team_size, power_distribution, high, med, low, voting_algorithm, show_values, weighted_utility,
;; errors, power_level, error_factor, permissivity, memory

avatars-own
[ power p_error permission own_A own_B own_diff own_optimal utility e_utility perceived match vote_own ]

to setup
  ;; each setup reassigns power and permission values to avatars
  ca

  ask patches [ set pcolor white ]
  set-default-shape turtles "circle"

  normalise

  instantiate

  power-scores

  reset-ticks
end

to go
  ;; each go reallocates option utilities but maintains power and permission values
  if ticks = rounds [ stop ]

  ask decisions [ die ]

  set-optimals

  ifelse baseline = true
    [ set yeas 0
      ask avatars [ if own_optimal = optimal [ set yeas yeas + 1 ] ]
      ]
    [ estimate-optimal
      decide ]

  tally

  ;; show_values prints roll-call output to console, intended for debugging
  if show_values = true
    [ print (word "optimal choice is " optimal)
      ask avatars [ roll-call ] ]

  ;; reset permission and loss values based on previous decision
  ;; the adaptive element in the model, permissivity, can be toggled on and off for comparisions
  if permissivity = true [ adjust ]

  tick
end

;; utility function to generate power values based on selected distribution
to-report random-weighted  [ values weights ]
 let selector (random-float sum weights)
 let running-sum 0
 (foreach values weights
 [ [ value weight ] ->
     set running-sum (running-sum + weight )
     if (running-sum > selector) [ report value ] ]
     )
end

;; creates avatars, set permission to 0, color accordingly and arrange.
to instantiate
   create-avatars team_size [
    set permission 0
    color-avatar
    layout-circle avatars (world-width / 2 - 4)
  ]
end

;; assign avatars power_scores based on selected distribution and link to others with greater or equal power
to power-scores
  if power_distribution = "normal" or power_distribution = "saddle" [
    set mu median(n-values power_level [i -> i + 1])
    set vari 2 * (power_level / 10) ^ 2 ]
  if power_distribution = "gamma" or power_distribution = "reverse gamma" [ set alpha (power_level / 10) * 3 ]

  ask avatars [
  if power_distribution = "constant" [ set power round(power_level / 2) ]
  if power_distribution = "uniform" [ set power ( random power_level ) + 1 ]
  if power_distribution = "normal" [
      set power round(random-normal mu vari)
      if power > power_level [ set power power_level ]
      if power < 1 [ set power 1 ]
  ]
  if power_distribution = "saddle" [
      set power round(random-normal mu vari)
      if power > power_level [ set power power_level ]
      if power < 1 [ set power 1 ]
      ifelse (power_level mod 2) = 0
      [ set power power + (-1)^(int(power / ceiling(mu))) * floor(mu)]
      [ ifelse power = mu
        [set power power + (-1)^(random 2) * (mu - 1)]
        [set power power + (-1)^(int(power / mu)) * (mu - 1)]
      ]
  ]
  if power_distribution = "gamma" [
      set power round(random-gamma alpha 1)
      if power > power_level [ set power power_level ]
      if power < 1 [ set power 1 ]
  ]
  if power_distribution = "reverse gamma" [
    set power round((power_level + 1) - ( random-gamma alpha 1 ))
    if power > power_level [ set power power_level ]
    if power < 1 [ set power 1 ]
  ]
  set size sqrt power
  ]

  ask avatars [
    create-links-to other avatars with [ power >= [ power ] of myself ]
  ]
end

;; assign avatars utility values for options A & B, determine own optimal and then find team optimal
to set-optimals
    ask avatars [
      set own_A random-float 10
      set own_B random-float 10
      set own_diff own_A - own_B
      ifelse own_diff > 0
      [ set own_optimal "A" ]
      [ set own_optimal "B" ]
    ]
    ifelse sum [ own_diff ] of avatars >  0
    [ set optimal "A" ]
    [ set optimal "B" ]
end

;; avatars estimates optimal with consideration of other avatar utilities
to estimate-optimal
  ask avatars [
    let x error_factor ; error runs between -x and x
    set p_error ( -1 * x + random-float( 2 * x ) )


    ifelse weighted_utility = true and power_distribution != "constant"
    [ set utility own_diff * power + sum [ [ p_error ] of myself + own_diff * ( 1 + ( power - [ power ] of myself ) / 10 ) ] of out-link-neighbors ]
    [ set utility own_diff * power + sum [ [ p_error ] of myself + own_diff ] of other avatars ]

    ifelse utility < 0
    [ set perceived "B" ]
    [ set perceived "A" ]
  ]
end

;; calculate number of prosocial votes from avatars
to decide
  set yeas 0

  ask avatars [
    ifelse own_optimal = optimal
      [ set match 1 ]
      [ set match 0 ]
    ifelse vote_own = 0
      [ ifelse voting_algorithm = "no weight"
        [ if perceived = optimal [ set yeas yeas + 1 ] ]
        [ if perceived = optimal [ set yeas yeas + power ] ]
      ]
      [ if own_optimal = optimal [ set yeas yeas + 1 ]
        set vote_own 0
      ]
  ]
end

;; create decision based on vote outcome, increment decision counts
to tally
  ask avatars [
    ifelse own_optimal = "A"
      [ set A A + 1 ]
      [ set B B + 1 ] ]

  ifelse voting_algorithm = "no weight" or baseline = true
    [ set criteria team_size / 2 ]
    [ set criteria ( sum [ power ] of avatars ) / 2 ]

  create-decisions 1 [
    if yeas > criteria
    [ set color green
      set choice 1
      set communal communal + 1 ]
    if yeas = criteria
    [ set color yellow
      set choice 0
      set ties ties + 1]
    if yeas < criteria
    [ set color red
      set choice -1
      set non_communal non_communal + 1 ]
    set size 4
    set shape "star"
    ]
  set p_communal (communal) / (communal + non_communal + ties) * 100
end

;; adaptive behaviour turned on by permissivity toggle on interface
;; avatars adjust permission values based on last decision outcome and reset network links based on new permission values
to adjust
  ask avatars [
    ; + + scenario
    if choice > 0 and own_optimal = optimal [
      if ( power - permission > 0 ) [ set permission permission + 1 ]
    ]
    ; + - scenario
    if choice > 0 and own_optimal != optimal [
      if ( power - permission < (power_level + 1) ) [ set permission permission - 1 ]
    ]
    ; - + scenario
    if choice < 0 and own_optimal = optimal [ ; - + scenario
      if ( power - permission > 0 ) [ set permission permission + 1 ]
    ]
    ; - - scenario
    if choice < 0 and own_optimal != optimal [
      ifelse memory = true
        [ set permission power - (power_level + 1) ]
        [ set vote_own 1
          set permission 0 ]
    ]

    create-links-to other avatars with [ power >= [ power - permission ] of myself ]
    color-avatar
  ]
end

;; utility function to color avatars
to color-avatar
  set color palette:scale-gradient palette:scheme-colors "Divergent"  "RdBu" (power_level + 1) permission (-1 * power_level) power_level
end

;; avatar attribute written to console in readable format
to roll-call
  print(word "decision: " ticks)
  print (word "avatar: " who)
  print (word "power: " power)
  print (word "interest in A and B: " own_A " and " own_B " with difference " own_diff)
  print (word "own optimal choice: " own_optimal)
  print (word "perception error: "  p_error )
  print (word "links: ")
  ask out-link-neighbors
  [
    print (word "  avatar: " who)
    print (word "    power: " power)
    print (word "    interest in A and B: " own_A " and " own_B " with difference " own_diff)
  ]
  print (word "utility for A: " utility " without error and " e_utility " with error.")
  print (word "percieved optimal choice: " perceived)
  print (word "permission :" permission)
  print (word "match? :" match)
  print (word "vote own? :" vote_own)
  print ("")
end

;; baseline values for prosocial decisions arranged consecutively by team size
to normalise
   set baseline_values array:from-list [ 0.50 0.842 0.587 0.826 0.628 0.819 0.652
     0.815 0.669 0.813 0.681 0.812 0.691 0.811 0.698 0.810 0.704 0.809
     0.710 0.809 0.714 0.808 0.719 0.808 0.722 0.808 0.725 0.808 0.728]
   set normaliser ( array:item baseline_values (team_size - 2))
end

;; the following customized reporters allow for capturing avatar level attributes through BehaviorSpace

to-report all_who
  let sorted sort [ who ] of avatars
  let index sorted
  let allwho []
  (foreach sorted index [ [ c d ] ->
    set allwho lput item 0 [ who ] of avatars with [ who = d ] allwho
  ])
  report allwho
end

to-report all_power
  let sorted sort [ who ] of avatars
  let index sorted
  let allpower []
  (foreach sorted index [ [ c d ] ->
    set allpower lput item 0 [ power ] of avatars with [ who = d ] allpower
  ])
  report allpower
end

to-report all_own
  let sorted sort [ who ] of avatars
  let index sorted
  let allown []
  (foreach sorted index [ [ c d ] ->
    set allown lput item 0 [ own_optimal ] of avatars with [ who = d ] allown
  ])
  report allown
end

to-report all_perceived
  let sorted sort [ who ] of avatars
  let index sorted
  let allperceived []
  (foreach sorted index [ [ c d ] ->
    set allperceived lput item 0 [ perceived ] of avatars with [ who = d ] allperceived
  ])
  report allperceived
end

to-report all_permission
  let sorted sort [ who ] of avatars
  let index sorted
  let allpermission []
  (foreach sorted index [ [ c d ] ->
    set allpermission lput item 0 [ permission ] of avatars with [ who = d ] allpermission
  ])
  report allpermission
end

to-report all_links
  let sorted sort [ who ] of avatars
  let index sorted
  let alllinks []
  (foreach sorted index [ [ c d ] ->
    set alllinks lput item 0 [ count link-neighbors ] of avatars with [ who = d ] alllinks
  ])
  report alllinks
end

;; an alternative method for collecting avatar-level attributes

to setup-outputfile
  set filename (word "FILENAME.csv")
  if ( file-exists? filename ) [ file-delete filename ]

  file-open filename
  ;file-type "behaviorspace_run_number"
  file-type "tick"
  file-type "voting,"
  file-type "team,"
  file-type "power distribution,"
  file-type "low,"
  file-type "med,"
  file-type "high,"
  file-type "percent communal,"
  file-print "normaliser"
  file-print "optimal"
  file-print "id"
  file-print "power"
  file-print "own optimal"
  file-print "perceived optimal"
  file-close
end

to write-data
  file-open filename
  file-type ( word ticks "," )
  file-type ( word voting_algorithm "," )
  file-type ( word team_size "," )
  file-type ( word power_distribution "," )
  file-type ( word p_communal "," )
  file-type ( word normaliser "," )
  file-type ( word optimal "," )
  file-type ( word who "," )
  file-type ( word power "," )
  file-type ( word own_optimal "," )
  file-print ( word perceived "," )
  file-close
end
@#$#@#$#@
GRAPHICS-WINDOW
243
10
728
496
-1
-1
14.455
1
10
1
1
1
0
0
0
1
-16
16
-16
16
0
0
1
ticks
30.0

BUTTON
29
43
201
76
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
29
147
118
180
go once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
29
186
205
219
team_size
team_size
2
30
5.0
1
1
NIL
HORIZONTAL

TEXTBOX
17
12
230
33
Empathy & Power Model 2
16
0.0
1

BUTTON
138
82
201
142
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
243
506
309
555
yea votes
yeas
0
1
12

CHOOSER
29
226
206
271
power_distribution
power_distribution
"constant" "uniform" "normal" "saddle" "gamma" "reverse gamma"
4

SWITCH
607
546
728
579
show_values
show_values
1
1
-1000

MONITOR
313
506
413
555
communal 
communal
170
1
12

MONITOR
417
506
518
555
non-communal
non_communal
0
1
12

MONITOR
522
506
582
555
ties
ties
0
1
12

CHOOSER
47
340
185
385
voting_algorithm
voting_algorithm
"no weight" "power weight"
0

MONITOR
734
238
824
287
% communal
(communal) / (communal + non_communal + ties) * 100
1
1
12

SWITCH
608
507
716
540
baseline
baseline
1
1
-1000

MONITOR
828
238
917
287
normalisation
normaliser * 100
1
1
12

SWITCH
50
301
182
334
weighted_utility
weighted_utility
0
1
-1000

PLOT
734
10
1066
233
Normalised Decisions
rounds
density
0.0
1.0
-2.0
2.0
true
false
"" ""
PENS
"communal" 1.0 0 -10899396 true "" "ifelse ticks < 1\n[ stop ]\n[ plot ( ( ( communal  / ( communal + non_communal + ties ) ) -  normaliser ) * 100 ) ]"
"zero-line" 1.0 0 -16777216 true "" "plot(0)"

SWITCH
60
478
178
511
permissivity
permissivity
0
1
-1000

MONITOR
243
558
348
603
mean permission
mean [ permission ] of avatars
1
1
11

INPUTBOX
30
82
132
142
rounds
50.0
1
0
Number

TEXTBOX
58
282
208
300
decision parameters
12
0.0
1

TEXTBOX
23
459
219
477
behavior modification parameters
12
0.0
1

BUTTON
819
492
896
552
experiment
repeat trials [\nreset-ticks\nask avatars [ die ]\nask links [ die ]\ninstantiate\npower-scores\ngo ]\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
739
492
814
552
trials
100.0
1
0
Number

MONITOR
452
558
549
603
max permission
max [ permission ] of avatars
17
1
11

MONITOR
353
558
447
603
min permission
min [ permission ] of avatars
17
1
11

SWITCH
57
517
181
550
memory
memory
1
1
-1000

INPUTBOX
41
391
112
451
error_factor
3.33
1
0
Number

PLOT
735
293
1069
479
permissions
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -13791810 true "" "plot mean [ permission ] of avatars"
"pen-1" 1.0 0 -16448764 true "" "plot(0)"

BUTTON
901
492
997
525
clear plots
clear-all-plots
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
1075
10
1235
130
power distribution
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 2 -1604481 true "" "histogram [ power ] of avatars"

INPUTBOX
119
391
193
451
power_level
10.0
1
0
Number

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.1
@#$#@#$#@
need-to-manually-make-preview-for-this-model
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="errorExperiment" repetitions="1000" sequentialRunOrder="false" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>setup
go</go>
    <timeLimit steps="50"/>
    <metric>communal</metric>
    <metric>normaliser</metric>
    <enumeratedValueSet variable="rounds">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="team_size">
      <value value="5"/>
      <value value="9"/>
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="power_distribution">
      <value value="&quot;gamma&quot;"/>
      <value value="&quot;reverse gamma&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weighted_utility">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="voting_algorithm">
      <value value="&quot;no weight&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="error_factor">
      <value value="0"/>
      <value value="0.5"/>
      <value value="1"/>
      <value value="1.5"/>
      <value value="2"/>
      <value value="2.5"/>
      <value value="3"/>
      <value value="3.5"/>
      <value value="4"/>
      <value value="4.5"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="power_level">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="permissivity">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="baseline">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show_values">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="distributionTest" repetitions="1000" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>communal</metric>
    <metric>normaliser</metric>
    <metric>optimal</metric>
    <metric>choice</metric>
    <metric>all_who</metric>
    <metric>all_power</metric>
    <metric>all_own</metric>
    <metric>all_perceived</metric>
    <metric>all_permission</metric>
    <metric>all_links</metric>
    <enumeratedValueSet variable="rounds">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="team_size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="power_distribution">
      <value value="&quot;constant&quot;"/>
      <value value="&quot;uniform&quot;"/>
      <value value="&quot;normal&quot;"/>
      <value value="&quot;saddle&quot;"/>
      <value value="&quot;gamma&quot;"/>
      <value value="&quot;reverse gamma&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weighted_utility">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="voting_algorithm">
      <value value="&quot;no weight&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="error_factor">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="power_level">
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="permissivity">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="baseline">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show_values">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="detailed" repetitions="1000" sequentialRunOrder="false" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>communal</metric>
    <metric>normaliser</metric>
    <metric>optimal</metric>
    <metric>choice</metric>
    <metric>all_who</metric>
    <metric>all_power</metric>
    <metric>all_own</metric>
    <metric>all_perceived</metric>
    <metric>all_permission</metric>
    <enumeratedValueSet variable="rounds">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="team_size">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="power_distribution">
      <value value="&quot;constant&quot;"/>
      <value value="&quot;uniform&quot;"/>
      <value value="&quot;normal&quot;"/>
      <value value="&quot;saddle&quot;"/>
      <value value="&quot;gamma&quot;"/>
      <value value="&quot;reverse gamma&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weighted_utility">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="voting_algorithm">
      <value value="&quot;no weight&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="error_factor">
      <value value="0"/>
      <value value="3.33"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="power_level">
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="permissivity">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="baseline">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show_values">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
